<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="am_ET">
<context>
    <name>AppearanceManager</name>
    <message>
        <source>Display scaling</source>
        <translation>መጠን ማሳያ</translation>
    </message>
    <message>
        <source>Log out for display scaling settings to take effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set successfully</source>
        <translation>ተሳክቶ ተፋጽሟል</translation>
    </message>
    <message>
        <source>Log Out Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start setting display scaling, please wait patiently</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>This system wallpaper is locked. Please contact your admin.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
